"""Password-related functions, e.g. for generating passwords."""

import os.path
import random
import string

DEFAULT_VALID_CHARACTERS = string.ascii_letters + string.digits


def random_character(valid_characters=None):
    """Generate a single random character from a sequence of valid characters. If valid_characters is None, letters
    (both lowercase and uppercase) and numbers will be used."""
    if valid_characters is None:
        valid_characters = DEFAULT_VALID_CHARACTERS
    return random.choice(valid_characters)


def random_password(length, valid_characters=None):
    """Generate a random password of given length, where valid characters can be defined - see random_character()
    docs"""
    password = ""
    # We do not use the iteration variable in the loop - using '_' for its name (best practice)
    for _ in range(length):
        password += random_character(valid_characters)
    return password


def is_strong_password(password):
    """Check whether the password is strong - i.e. contains at least 6 characters and no dictionary word"""
    if len(password) < 6:
        return False
    # Open words.txt from the same directory as this file
    with open(os.path.join(os.path.dirname(__file__), "words.txt"), "r") as handle:
        # Each time this function is called, the file is re-read (may not be desired)
        for word in handle:
            word = word.strip()
            # We do not want to consider dictionary words with length less than 5
            if len(word) >= 5 and word.lower() in password.lower():
                return False
    return True
