import unittest
import password


class TestPasswordFunctions(unittest.TestCase):

    def test_random_characters(self):
        # The same as below, but with a nicer message when the assert fails
        self.assertIsInstance(password.random_character(), str)
        # self.assertTrue(isinstance(password.random_character(), str))

        self.assertEqual(len(password.random_character()), 1)
        self.assertEqual(password.random_character("a"), "a")

        # The same as below, but with a nicer message when the assert fails
        self.assertIn(password.random_character("ab"), "ab")
        # self.assertTrue(password.random_character("ab") in "ab)

        self.assertIn(password.random_character(), password.DEFAULT_VALID_CHARACTERS)

        # Test whether random_character() raises TypeError when a parameter of incorrect type provided
        with self.assertRaises(TypeError):
            password.random_character(2)

    def test_random_password(self):
        for length in [1, 3, 8]:
            # We make the asserts for each of given lengths
            self.assertIsInstance(password.random_password(length), str)
            self.assertEqual(len(password.random_password(length)), length)

    def test_is_strong_password(self):
        self.assertTrue(password.is_strong_password("456.5fs8GGdf"))
        self.assertFalse(password.is_strong_password(""))
        self.assertFalse(password.is_strong_password("aaa"))
        with self.assertRaises(TypeError):
            password.is_strong_password(None)

        # Test for passwords that contain a dictionary word
        self.assertFalse(password.is_strong_password("Student678"))


if __name__ == '__main__':
    unittest.main()
